##########################################################################
#
# FILE  common.mk
# Copyright (c) 2004, 2005, 2006 Daniel Kahlin <daniel@kahlin.net>
# Written by Daniel Kahlin <daniel@kahlin.net>
# $Id: common.mk,v 1.4 2006-11-29 20:10:08 tlr Exp $
#
# DESCRIPTION
#   Common Makefile definitions.
#   Include this after setting the relative path to this directory
#   in the PACKAGE_ROOT variable.
#
#   i.e (for a subdirectory to this directory):
#       SUBDIRS=subdir1 subdir2 subdir3
#
#       PACKAGE_ROOT=..
#       include $(PACKAGE_ROOT)/common.mk
#
#   The standard targets supported are:
#
#     all::    build all target binaries.
#
#     doc::    build all documentation.
#
#     clean::  clean all objects, temporaries and target binaries
#
#     distclean:: normal clean + remove files created by configure 
#
######

BINARY=dtvtrans.exe
POST=obj
ARCHOBJS=win32/port.obj win32/timer.obj win32/dtvtrans.res

# calculate windows version sequence from the VERSION variable
VERSION32=$(shell echo $(VERSION) | awk -F . '{ printf "%d,%d,%d,%d",$$1,$$2,$$3,$$4 }')

RC=rc.exe
RCFLAGS=-d NDEBUG \
        -d RC_PACKAGE=\"$(PACKAGE)\" \
        -d RC_VERSION=\"$(VERSION)\" \
        -d RC_FILEVERSION=$(VERSION32) \
        -d RC_PRODUCTVERSION=$(VERSION32)

CC=cl.exe
CFLAGS_STATIC=-c -nologo \
      -W3 -O2 -Ob1 -GF -EHsc -MT -Gy \
      -I $(ARCH)/ \
      -D WIN32 -D _WINDOWS  \
      -D PACKAGE=\"$(PACKAGE)\" \
      -D VERSION=\"$(VERSION)\" \
      -D IS_WINDOWS

LD=link.exe
LDFLAGS=-INCREMENTAL:NO -NOLOGO /opt:nowin98  /subsystem:console
#LDFLAGS=-INCREMENTAL:NO -NOLOGO /opt:nowin98 /entry:mainCRTStartup /subsystem:console

define COMPILE_STATIC
	$(CC) $(CFLAGS_STATIC) -Fo"$@" $<
endef

define RESCOMP
	$(RC) $(RCFLAGS) -fo"$@" $<
endef

define DOLINK
	$(LD) $(LDFLAGS) $(LIBS) -OUT:"$@"  $^  
	cp $@ $(PACKAGE_ROOT)/bin
endef


# additional rules for windows builds.
.SUFFIXES: .obj .cpp
%.obj: %.cpp
	$(COMPILE_STATIC)

clean::
	rm -f *.obj *.res
	rm -f *.lib *.exp *.pdb
	rm -f *.dll *.exe


# eof
